#[non_exhaustive]pub enum RointeError {
Auth(String),
Network(Error),
Firebase(String),
DeviceNotFound(String),
Json(Error),
}Expand description
All errors that can be returned by rointe-core.
This enum is #[non_exhaustive] — new variants may be added in future
minor versions without a breaking change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auth(String)
Authentication failed (bad credentials, expired token, etc.).
Network(Error)
An underlying HTTP transport error from reqwest.
Firebase(String)
The Firebase Realtime Database returned an unexpected response or the response could not be parsed as the expected schema.
DeviceNotFound(String)
A device ID was referenced that does not exist in the installation.
Json(Error)
JSON serialisation or deserialisation failed.